### FileAutomation

### Documentation

* TODO

---
> Project Kanban \
> https://github.com/orgs/Intergration-Automation-Testing/projects/2 \
> FileAutomation is used to manager files and dirs.


---
### Features
* Process multi file.
  * copy file.
  * copy specify extension file.
  * copy all file to dir.
  * rename file.
  * remove file.
* Process multi dir.
  * copy dir.
  * remove dir.
  * rename dir.
  * create dir.
* Process zip files.
  * zip a dir.
  * zip a file.
  * read zip file.
  * unzip file on zip.
  * un zip all file on zip.
  * show zip info.
  * show file on zip info.

## install
> pip install automation_file

## Requires
> python 3.8 or later

### Architecture Diagram


* TODO
